#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 topograph
version:              1.0.1
visibility:           public
id:                   topograph-1.0.1-JspQBPBVjYS5CCoPFL3VKC
key:                  topograph-1.0.1-JspQBPBVjYS5CCoPFL3VKC
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  007b631137ff41dfa5f53ca03653a4b2
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.6.6/site-local/topograph-1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/topograph-1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/topograph-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.1-JspQBPBVjYS5CCoPFL3VKC
depends:
    base-4.18.2.1 base-orphans-0.9.4-F93g79l8c15JRU0CelkMYu
    containers-0.6.7 vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

